@@ -570,10 +570,7 @@ class FTS5Model(BaseFTSModel):
 
     @classmethod
     def rank(cls, *args):
-        if args:
-            return cls.bm25(*args)
-        else:
-            return SQL('rank')
+        return cls.bm25(*args) if args else SQL('rank')
 
     @classmethod
     def bm25(cls, *weights):
@@ -966,8 +963,8 @@ if CYTHON_SQLITE_EXTENSIONS:
 
     def __status__(flag, return_highwater=False):
         """
-        Expose a sqlite3_status() call for a particular flag as a property of the
-        Database object.
+        Expose a sqlite3_status() call for a particular flag as a property of
+        the Database object.
         """
         def getter(self):
             result = sqlite_get_status(flag)
@@ -976,9 +973,9 @@ if CYTHON_SQLITE_EXTENSIONS:
 
     def __dbstatus__(flag, return_highwater=False, return_current=False):
         """
-        Expose a sqlite3_dbstatus() call for a particular flag as a property of the
-        Database instance. Unlike sqlite3_status(), the dbstatus properties pertain
-        to the current connection.
+        Expose a sqlite3_dbstatus() call for a particular flag as a property of
+        the Database instance. Unlike sqlite3_status(), the dbstatus properties
+        pertain to the current connection.
         """
         def getter(self):
             result = sqlite_get_db_status(self._state.conn, flag)
